/*!
 * vue-router-layout v0.1.1
 * https://github.com/ktsn/vue-router-layout
 *
 * @license
 * Copyright (c) 2018 katashin
 * Released under the MIT license
 * https://github.com/ktsn/vue-router-layout/blob/master/LICENSE
 */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Vue = _interopDefault(require('vue'));

function findLayoutName(matched) {
    var reversed = matched.slice().reverse();
    var layoutName = 'default';
    for (var _i = 0, reversed_1 = reversed; _i < reversed_1.length; _i++) {
        var record = reversed_1[_i];
        var Component = record.components.default;
        if (Component) {
            var name_1 = typeof Component === 'function'
                ? Component.options.layout
                : Component.layout;
            if (name_1) {
                layoutName = name_1;
                break;
            }
        }
    }
    return layoutName;
}
function createRouterLayout(resolve) {
    return Vue.extend({
        name: 'RouterLayout',
        data: function () {
            return {
                layoutName: undefined,
                layouts: Object.create(null)
            };
        },
        watch: {
            layoutName: function (name) {
                if (!this.layouts[name]) {
                    this.$set(this.layouts, name, function () { return resolve(name); });
                }
            }
        },
        beforeRouteEnter: function (to, _from, next) {
            next(function (vm) {
                vm.layoutName = findLayoutName(to.matched);
            });
        },
        beforeRouteUpdate: function (to, _from, next) {
            this.layoutName = findLayoutName(to.matched);
            next();
        },
        render: function (h) {
            var layout = this.layoutName && this.layouts[this.layoutName];
            if (!layout) {
                return h();
            }
            return h(layout, {
                key: this.layoutName
            });
        }
    });
}

exports.createRouterLayout = createRouterLayout;
